@font-face{font-family:BackFont;src:url(/BackFont-Regular.otf)}#outermost[data-v-b41abd6a]{width:100vw;height:100vh;position:relative;background-color:var(--v367e3597)}#topButtonBarFlex[data-v-b41abd6a]{height:calc(2rem + 2px);position:relative;gap:1rem;padding:.5rem;border-bottom:1px solid var(--v2f7d2bcd)}#controlSpace{&[data-v-b41abd6a]{height:calc(100% - 2rem - 3px);position:relative;overflow:hidden}>.n-layout[data-v-b41abd6a]{max-height:100%}}
