import{d,bk as c,bl as m,c as t,bm as p,bn as a,bo as e,a as s,bx as _,bw as r,o as n}from"./index-Ci_yf8On.js";import{N as l}from"./Card-AFZD9zEb.js";import"./Close-BZdulABt.js";const f={style:{display:"grid",gap:"1rem",padding:"1rem",position:"relative","overflow-x":"hidden"}},u={key:0},i="https://github.com/op200/windows_font_manager",k=d({__name:"About",setup(b){const{back_info:o}=c(m());return(h,g)=>(n(),t("div",f,[p(e(l),{title:"Windows Font Manager"},{"header-extra":a(()=>[s("a",{href:i},r(i))]),default:a(()=>[s("div",null,[e(o)?(n(),t("span",u,"v"+r(e(o).version),1)):_("",!0)])]),_:1})]))}});export{k as default};
